@@ -18,27 +18,21 @@ class Background:
     ideal = ()
     bond = ()
     flaw = ()
-    random_trait_type = TruffleShuffle(("Trait", "Ideal", "Bond", "Flaw"))
 
-    def __repr__(self):
-        traits = {
-            "Trait": f"{self.trait}",
-            "Ideal": f"{self.ideal}",
-            "Bond": f"{self.bond}",
-            "Flaw": f"{self.flaw}",
-        }
-        trait_type = self.random_trait_type()
+    def __str__(self):
         output = (
-            f"{self.name}",
-            f"{self.feature}",
-            f"{trait_type}: {traits[trait_type]}",
+            f"{self.name}, {self.feature}",
+            # f"Trait: {self.trait}",
+            f"Ideal: {self.ideal}",
+            # f"Bond: {self.bond}",
+            f"Flaw: {self.flaw}",
         )
         return "\n".join(output)
 
 
 class Acolyte(Background):
     name = "Acolyte"
-    feature = "Specialty: Shelter of the Faithful"
+    feature = "Shelter of the Faithful"
     skills = ("Insight WIS", "Religion INT")
     proficiencies = ("Choose two languages", )
     equipment = (
@@ -47,13 +41,14 @@ class Acolyte(Background):
     )
     random_trait = TruffleShuffle((
         "I idolize a particular hero of my faith, and constantly refer to that person's deeds and example.",
-        "I see omens in every event and action. The gods try to speak to us, we just need to listen.",
+        "I see omens in every event and action.",
+        "The gods try to speak to us, we just need to listen.",
         "Nothing can shake my optimistic attitude.",
-        "I quote (or misquote) sacred texts and proverbs in almost every situation.",
-        "I am tolerant (or intolerant) of other faiths and respect (or condemn) the worship of other gods.",
+        "I quote sacred texts and proverbs in almost every situation.",
+        "I am tolerant of other faiths and respect the worship of other gods.",
+        "I am intolerant of other faiths and condemn the worship of other gods.",
         "I've enjoyed fine food, drink, and high society among my temple's elite. Rough living grates on me.",
-        "I've spent so long in the temple that I have little practical experience dealing with people in the "
-        "outside world."
+        "I've spent so long in the temple that I have little practical experience dealing with people in the outside world."
     ))
     random_ideal = TruffleShuffle((
         "Tradition. The ancient traditions of worship and sacrifice must be preserved and upheld.",
@@ -61,8 +56,7 @@ class Acolyte(Background):
         "Change. We must help bring about the changes the gods are constantly working in the world.",
         "Power. I hope to one day rise to the top of my faith's religious hierarchy.",
         "Faith. I trust that my deity will guide my actions, I have faith that if I work hard, things will go well.",
-        "Aspiration. I seek to prove myself worthy of my god's favor by matching my actions "
-        "against his or her teachings."
+        "Aspiration. I seek to prove myself worthy of my god's favor by matching my actions against his or her teachings."
     ))
     random_bond = TruffleShuffle((
         "I would die to recover an ancient relic of my faith that was lost long ago.",
@@ -91,12 +85,10 @@ class Acolyte(Background):
 class Charlatan(Background):
     name = "Charlatan"
     random_feature = TruffleShuffle((
-        "I cheat at games of chance.",
-        "I shave coins or forge documents.",
-        "I insinuate myself into people's lives to prey on their weakness and secure their fortunes.",
-        "I put on new identities like clothes.",
-        "I run sleight-of-hand cons on street corners.",
-        "I convince people that worthless junk is worth their hard-earned money."
+        "Cheater",
+        "Forgery",
+        "Con-artist",
+        "Disguises",
     ))
     skills = ("Deception CHA", "Sleight of Hand DEX")
     proficiencies = ("Disguise kit", "forgery kit")
@@ -142,7 +134,7 @@ class Charlatan(Background):
     ))
 
     def __init__(self):
-        self.feature = f"Favorite Scam: {self.random_feature()}"
+        self.feature = self.random_feature()
         self.trait = self.random_trait()
         self.ideal = self.random_ideal()
         self.bond = self.random_bond()
@@ -153,12 +145,11 @@ class Criminal(Background):
     name = "Criminal"
     random_feature = TruffleShuffle((
         "Blackmailer",
-        "Highway robber",
+        "Robber",
         "Burglar",
-        "Hired killer",
+        "Assassin",
         "Enforcer",
         "Pickpocket",
-        "Fence",
         "Smuggler",
         "Spy",
     ))
@@ -203,7 +194,7 @@ class Criminal(Background):
     ))
 
     def __init__(self):
-        self.feature = f"Specialty: {self.random_feature()}"
+        self.feature = self.random_feature()
         self.trait = self.random_trait()
         self.ideal = self.random_ideal()
         self.bond = self.random_bond()
@@ -246,7 +237,7 @@ class Entertainer(Background):
         "Tradition. The stories, legends, and songs of the past must never be forgotten, for they teach us who we are.",
         "Creativity. The world is in need of new ideas and bold action.",
         "Greed. I'm only in it for the money and fame.",
-        "People. I like seeing the smiles on people's faces when I perform. That' s all that matters.",
+        "People. I like seeing the smiles on people's faces when I perform. That's all that matters.",
         "Honesty. Art should reflect the soul; it should come from within and reveal who we really are.",
     ))
     random_bond = TruffleShuffle((
@@ -267,7 +258,7 @@ class Entertainer(Background):
     ))
 
     def __init__(self):
-        self.feature = f"Routine: {self.random_feature()}"
+        self.feature = self.random_feature()
         self.trait = self.random_trait()
         self.ideal = self.random_ideal()
         self.bond = self.random_bond()
@@ -276,18 +267,7 @@ class Entertainer(Background):
 
 class FolkHero(Background):
     name = "Folk Hero"
-    random_feature = TruffleShuffle((
-        "I stood up to a tyrant' s agents.",
-        "I saved people during a natural disaster.",
-        "I stood alone against a terrible monster.",
-        "I stole from a corrupt merchant to help the poor.",
-        "I led a militia to fight off an invading army.",
-        "I broke into a tyrant' s castle and stole weapons to arm the people.",
-        "I trained the peasantry to use farm implements as weapons against a tyrant's soldiers.",
-        "A lord rescinded an unpopular decree after I led a symbolic act against it.",
-        "A celestial, fey, or similar creature gave me a blessing or revealed my secret origin.",
-        "Recruited into a lord's army, I rose to leadership and was commended for my heroism.",
-    ))
+    feature = "Hero of the People"
     skills = ("Animal Handling WIS", "Survival WIS")
     proficiencies = ("One type of artisan's tools", "vehicles (land)")
     equipment = (
@@ -331,7 +311,6 @@ class FolkHero(Background):
     ))
 
     def __init__(self):
-        self.feature = f"Defining Event: {self.random_feature()}"
         self.trait = self.random_trait()
         self.ideal = self.random_ideal()
         self.bond = self.random_bond()
@@ -341,28 +320,25 @@ class FolkHero(Background):
 class GuildArtisan(Background):
     name = "Guild Artisan"
     random_feature = TruffleShuffle((
-        "Alchemists and apothecaries",
-        "Armorers, locksmiths, and fine smiths",
-        "Brewers, distillers, and vintners",
-        "Calligraphers, scribes, and scriveners",
-        "Carpenters, roofers, and plasterers",
-        "Cartographers, surveyors, and chart-makers",
-        "Cobblers and shoemakers",
-        "Cooks and bakers",
-        "Glassblowers and glaziers",
-        "Festivals and tournaments",
-        "Jewelers and gem cutters",
-        "Leather workers, skinners, and tanners",
-        "Masons and stone cutters",
-        "Painters and sign-makers",
-        "Potters and tile-makers",
-        "Shipwrights",
-        "Smiths and metal-forgers",
-        "Tinkers, pewterers, and casters",
-        "Wagon-makers and wheelwrights",
-        "Weavers and dyers",
-        "Woodcarvers, coopers, and bowyers",
-        "Merchants, traders and caravans",
+        "Alchemist",
+        "Armorer",
+        "Brewer",
+        "Calligrapher",
+        "Carpenter",
+        "Cartographer",
+        "Cobbler",
+        "Cook",
+        "Glassblowers",
+        "Jeweler",
+        "Leather Worker",
+        "Mason",
+        "Painter",
+        "Potter",
+        "Shipwright",
+        "Blacksmith",
+        "Tinker",
+        "Wheelwright",
+        "Weaver",
     ))
     skills = ("Insight WIS", "Persuasion CHA")
     proficiencies = ("One type of artisan's tools", "and one language of your choice")
@@ -397,20 +373,20 @@ class GuildArtisan(Background):
         "someone worthy.",
         "I owe my guild a great debt for forging me into the person I am today.",
         "I pursue wealth to secure someone's love.",
-        "One day I will return to my guild and prove that I am the greatest artisan of them all."
-        "I will get revenge on the evil forces that destroyed my place of business and ruined my livelihood.",
+        "One day I will return to my guild and prove that I am the greatest artisan of them all.",
+        "I will get revenge on the evil forces that destroyed my business.",
     ))
     random_flaw = TruffleShuffle((
         "I'll do anything to get my hands on something rare or priceless.",
         "I'm quick to assume that someone is trying to cheat me.",
-        "No one must ever learn that I once stole money from guild coffers."
+        "No one must ever learn that I once stole money from guild coffers.",
         "I'm never satisfied with what I have—I always want more.",
         "I would kill to acquire a noble title.",
-        "I'm horribly jealous of anyone who can outshine my handiwork. Everywhere I go, I'm surrounded by rivals.",
+        "I'm horribly jealous of anyone who can outshine my handiwork.",
     ))
 
     def __init__(self):
-        self.feature = f"Guild Business: {self.random_feature()}"
+        self.feature = self.random_feature()
         self.trait = self.random_trait()
         self.ideal = self.random_ideal()
         self.bond = self.random_bond()
@@ -420,14 +396,13 @@ class GuildArtisan(Background):
 class Hermit(Background):
     name = "Hermit"
     random_feature = TruffleShuffle((
-        "I was searching for spiritual enlightenment.",
-        "I was partaking of communal living in accordance with the dictates of a religious order.",
-        "I was exiled for a crime I didn't commit.",
-        "I retreated from society after a life-altering event.",
-        "I needed a quiet place to work on my art, literature, music, or manifesto.",
-        "I needed to commune with nature, far from civilization.",
-        "I was the caretaker of an ancient ruin or relic.",
-        "I was a pilgrim in search of a person, place, or relic of spiritual significance.",
+        "Spiritual Enlightenment",
+        "Religious Mandate",
+        "Exiled Criminal",
+        "Retired",
+        "Secluded Artist",
+        "Communing with Nature",
+        "Caretaker of a Relic",
     ))
     skills = ("Medicine WIS", "Religion INT")
     proficiencies = ("Herbalism kit", "and one language of your choice.")
@@ -471,7 +446,7 @@ class Hermit(Background):
     ))
 
     def __init__(self):
-        self.feature = f"Life of Seclusion: {self.random_feature()}"
+        self.feature = self.random_feature()
         self.trait = self.random_trait()
         self.ideal = self.random_ideal()
         self.bond = self.random_bond()
@@ -480,7 +455,7 @@ class Hermit(Background):
 
 class Noble(Background):
     name = "Noble"
-    feature = "Specialty: Position of Privilege"
+    feature = "Position of Privilege"
     skills = ("History INT", "Persuasion CHA")
     proficiencies = ("One type of gaming set", "and one language of your choice")
     equipment = ("A set of fine clothes", "a signet ring", "a scroll of pedigree", "and a purse containing 25 gp.")
@@ -489,7 +464,7 @@ class Noble(Background):
         "The common folk love me for my kindness and generosity.",
         "No one could doubt by looking at my regal bearing that I am a cut above the unwashed masses.",
         "I take great pains to always look my best and follow the latest fashions.",
-        "I don' t like to get my hands dirty, and I won' t be caught dead in unsuitable accommodations.",
+        "I don't like to get my hands dirty, and I won't be caught dead in unsuitable accommodations.",
         "Despite my noble birth, I do not place myself above other folk. We all have the same blood.",
         "My favor, once lost, is lost forever.",
         "If you do me an injury, I will crush you, ruin your name, and salt your fields.",
@@ -534,13 +509,12 @@ class Outlander(Background):
         "Forester",
         "Trapper",
         "Homesteader",
-        "Guide",
-        "Exile or outcast",
-        "Bounty hunter",
+        "Wilderness Guide",
+        "Outcast",
+        "Bounty Hunter",
         "Pilgrim",
-        "Tribal nomad",
-        "Hunter-gatherer",
-        "Tribal marauder",
+        "Tribal Nomad",
+        "Tribal Marauder",
     ))
     skills = ("Athletics STR", "Survival WIS")
     proficiencies = ("One type of musical instrument", "and one language of your choice")
@@ -586,7 +560,7 @@ class Outlander(Background):
     ))
 
     def __init__(self):
-        self.feature = f"Origin: {self.random_feature()}"
+        self.feature = self.random_feature()
         self.trait = self.random_trait()
         self.ideal = self.random_ideal()
         self.bond = self.random_bond()
@@ -598,11 +572,10 @@ class Sage(Background):
     random_feature = TruffleShuffle((
         "Alchemist",
         "Astronomer",
-        "Discredited academic",
         "Librarian",
         "Professor",
-        "Arcane lore",
-        "Wizard's apprentice",
+        "Arcane Lore Master",
+        "Wizard's Apprentice",
         "Scribe",
     ))
     skills = ("Arcana INT", "History INT")
@@ -650,7 +623,7 @@ class Sage(Background):
     ))
 
     def __init__(self):
-        self.feature = f"Specialty: {self.random_feature()}"
+        self.feature = self.random_feature()
         self.trait = self.random_trait()
         self.ideal = self.random_ideal()
         self.bond = self.random_bond()
@@ -659,7 +632,7 @@ class Sage(Background):
 
 class Sailor(Background):
     name = "Sailor"
-    feature = "Specialty: Ship's Passage"
+    feature = "Ship's Passage"
     skills = ("Athletics STR", "Perception WIS")
     proficiencies = ("Navigator's tools", "vehicles (water)")
     equipment = (
@@ -719,8 +692,7 @@ class Soldier(Background):
         "Cavalry",
         "Healer",
         "Quartermaster",
-        "Standard bearer",
-        "Support staff (cook, blacksmith, or the like)",
+        "Standard Bearer",
     ))
     skills = ("Athletics STR", "Intimidation CHA")
     proficiencies = ("One type of gaming set", "vehicles (land)")
@@ -758,14 +730,14 @@ class Soldier(Background):
     random_flaw = TruffleShuffle((
         "The monstrous enemy we faced in battle still leaves me quivering with fear.",
         "I have little respect for anyone who is not a proven warrior.",
-        "I made a terrible mistake in battle cost many lives— and I would do anything to keep that mistake secret.",
+        "I made a terrible mistake in battle, it cost many lives and I would do anything to keep that mistake secret.",
         "My hatred of my enemies is blind and unreasoning.",
         "I obey the law, even if the law causes misery.",
         "I'd rather eat my armor than admit when I'm wrong.",
     ))
 
     def __init__(self):
-        self.feature = f"Specialty: {self.random_feature()}"
+        self.feature = self.random_feature()
         self.trait = self.random_trait()
         self.ideal = self.random_ideal()
         self.bond = self.random_bond()
@@ -774,7 +746,7 @@ class Soldier(Background):
 
 class Urchin(Background):
     name = "Urchin"
-    feature = "Specialty: City Secrets"
+    feature = "City Secrets"
     skills = ("Sleight of Hand DEX", "Stealth DEX")
     proficiencies = ("Disguise kit", "thieves' tools")
     equipment = (
@@ -788,7 +760,7 @@ class Urchin(Background):
         "I like to squeeze into small places where no one else can get to me.",
         "I sleep with my back to a wall or tree, with everything I own wrapped in a bundle in my arms.",
         "I eat like a pig and have bad manners.",
-        "I think anyone who' s nice to me is hiding evil intent.",
+        "I think anyone who's nice to me is hiding evil intent.",
         "I don't like to bathe.",
         "I bluntly say what other people are hinting at or hiding.",
     ))
@@ -845,5 +817,5 @@ random_background = TruffleShuffle(backgrounds)
 
 if __name__ == "__main__":
     print()
-    for back in backgrounds:
-        print(back(), '\n')
+    for background in backgrounds:
+        print(background(), '\n')
