@@ -105,7 +105,7 @@ class Npc:
     def ability_scores(self):
         return ", ".join(f"{key} {val} ({self.stat_mod_str[key]})" for key, val in self.stats.items())
 
-    def __repr__(self):
+    def __str__(self):
         self.output = (
             f"NPC: {self.profession}",
             f"Race: {self.race}",
@@ -151,7 +151,7 @@ class QuestGiver(Npc):
         self.skill = self.skill_list()
         self.chest = get_loot(max(-3, self.cr - 15), is_villain=True)
 
-    def __repr__(self):
+    def __str__(self):
         self.output = (
             f"NPC: Secondary Quest Giver",
             f"Race: {self.race}",
@@ -190,7 +190,7 @@ class ShopKeeper(Npc):
         self.trinket_price = f"{BasicGear(5).price}"
         self.for_sale_names = [f"  {val.name} ({val.id})" for val in self.for_sale]
 
-    def __repr__(self):
+    def __str__(self):
         self.output = (
             f"NPC: {self.profession}",
             f"Race: {self.race}",
@@ -210,7 +210,7 @@ class PotionDealer(Npc):
         self.profession = 'Potion Dealer'
         self.for_sale = sorted([f"  {Potion(cr)}" for _ in range(dice(3, 4))])
 
-    def __repr__(self):
+    def __str__(self):
         self.output = (
             f"NPC: {self.profession}",
             f"Race: {self.race}",
@@ -299,7 +299,7 @@ class Mercenary(Npc):
                 skills.add(f"{random_value(npc_dict['skills'][ability])}")
         return list(skills)
 
-    def __repr__(self):
+    def __str__(self):
         coinage = ["Copper", "Silver", "Electrum", "Gold", "Platinum"]
         price_dom = coinage[smart_clamp(round(self.player.level / 5), 0, 4)]
         self.output = (
@@ -337,7 +337,7 @@ class Adventurer(Mercenary):
         super().__init__(cr + 1, race, pcc)
         self.goal = self.goals()
 
-    def __repr__(self):
+    def __str__(self):
         self.output = (
             f"NPC: Adventurer",
             f"Class: {self.player.cls.name}",
@@ -373,7 +373,7 @@ class VillainNPC(Adventurer):
         self.treasure = get_loot(self.level, is_villain=True)
         self.xp = Villain(self.cr).xp
 
-    def __repr__(self):
+    def __str__(self):
         self.output = (
             f"NPC: {self.name}",
             f"Class: {self.player.cls.name}",
@@ -432,6 +432,4 @@ def random_dungeon_npc(cr=1, room_name="Any"):
 
 if __name__ == "__main__":
     print()
-    print(Adventurer(d(1)))
-    print(Mercenary(d(1)))
-    print(VillainNPC(d(1)))
+    print(PotionDealer(d(10)))
