@@ -1,4 +1,6 @@
 from Fortuna import *
+
+from DungeonGenerator.backgrounds import random_background
 from DungeonGenerator.gear_lib import *
 from DungeonGenerator.monsters_lib import damage_type_cat
 from DungeonGenerator.treasure import Loot, get_loot, magic_table_by_cr
@@ -15,7 +17,7 @@ class Base:
         return dice(num_dam_dice, self.damage_dice) + bonus
 
 
-class Squire(Base):
+class Apprentice(Base):
     hd = 4
     stats = {
         'STR': ability_dice(3),
@@ -529,6 +531,7 @@ class Player:
         self.set_att_bonus()
         self.saves = list(self.cls.save_prof)
         self.saving_throws = self.set_saves()
+        self.background = random_background()
         self.loot = Loot()
         dam_mod = smart_clamp(self.level // 4, 1, 4)
         dam_bonus = self.stat_mod[self.cls.fav_stat] + self.magic_bonus
@@ -587,6 +590,7 @@ class Player:
             f"Level: {self.level}",
             f"Total XP: {self.xp}",
             f"Race: {self.race}",
+            f"Background: {self.background}",
             f"{self.ability_scores}",
             f"Proficiency Bonus: {self.prof_bonus_str}",
             f"Hit Points: {self.health}",
@@ -714,17 +718,17 @@ class Party:
             self.gold_party(gold_level=10)
         elif strat == "silver":
             self.gold_party(gold_level=5)
-        elif strat == "squires":
-            self.squires()
+        elif strat == "apprentice":
+            self.apprentice()
         else:
             self.default_party()
 
-    def squires(self):
-        self.party_list.append(Player(Squire, self.level, self.race))
-        self.party_list.append(Player(Squire, self.level, self.race))
-        self.party_list.append(Player(Squire, self.level, self.race))
-        self.party_list.append(Player(Squire, self.level, self.race))
-        self.party_list.append(Player(Squire, self.level, self.race))
+    def apprentice(self):
+        self.party_list.append(Player(Apprentice, self.level, self.race))
+        self.party_list.append(Player(Apprentice, self.level, self.race))
+        self.party_list.append(Player(Apprentice, self.level, self.race))
+        self.party_list.append(Player(Apprentice, self.level, self.race))
+        self.party_list.append(Player(Apprentice, self.level, self.race))
 
     def default_party(self):
         self.party_list.append(Player(random_tank(), self.level, self.race))
@@ -767,5 +771,5 @@ class Party:
 
 if __name__ == '__main__':
     print()
-    pc_party = Party(level=1, strat="squires")
+    pc_party = Party(level=10)
     print(pc_party)
