@@ -78,7 +78,7 @@ class Loot:
         return len(self.magic_items)
 
     def reduce_loot(self):
-        output = ['']
+        output = []
         for coin in self.coinage:
             if self.coinage[coin] > 0:
                 if coin == "Gems" or coin == "Jewels":
@@ -88,16 +88,14 @@ class Loot:
         if self.magic_items:
             for itm in sorted(list(set(self.magic_items))):
                 output.append(itm)
-        if len(output) == 2:
-            output = output[1:2]
-        elif len(output) == 1:
+        if len(output) == 0:
             output = ['Empty']
         return ", ".join(output) if len(output) > 1 else output[0]
 
     def set_loot(self, loot_data):
         loot = cumulative_weighted_choice(loot_data)
         for key in loot:
-            if key is "Magic_Items":
+            if key == "Magic_Items":
                 for itm in loot[key]:
                     table, amount = itm
                     if amount == 1:
@@ -826,5 +824,4 @@ def no_coin(loot: Loot) -> Loot:
 
 if __name__ == '__main__':
     print()
-    for crx in range(-3, 31):
-        print(magic_table_by_cr(crx))
+    print(RankOneHoardLoot())
